@@ -3,7 +3,7 @@
 * @author  ARMCNC site:www.armcnc.net github:armcnc.github.io
 ******************************************************************************
 """
-
+import copy
 import threading
 import linuxcnc
 
@@ -42,6 +42,7 @@ class Status:
                         "control": int(self.father.framework.machine.get_user_config_value("BASE", "CONTROL") or 0),
                         "increments": [value.replace("mm", "") for value in inifile.find("DISPLAY", "INCREMENTS").split(",")],
                         "axes": list(inifile.find("TRAJ", "COORDINATES")) or [],
+                        "data": self.father.framework.machine.set_data(self.father.framework.machine.info["g5x_index"]),
                         "linear_units": inifile.find("TRAJ", "LINEAR_UNITS") or "mm",
                         "angular_units": inifile.find("TRAJ", "ANGULAR_UNITS") or "degree",
                         "estop": self.father.framework.machine.info["estop"],
@@ -53,8 +54,7 @@ class Status:
                         "homed": self.father.framework.machine.info["homed"],
                         "is_homed": self.father.framework.armcnc.command.is_homed(),
                         "motion_line": self.father.framework.machine.info["motion_line"],
-                        "current_vel": int(self.father.framework.machine.info["current_vel"]),
-                        "offset": self.father.framework.machine.set_offset(self.father.framework.machine.info["g5x_index"], self.father.framework.machine.info["g5x_offset"], self.father.framework.machine.info["g92_offset"]),
+                        "current_velocity": float(self.father.framework.machine.info["current_vel"]),
                         "spindle": {
                             "enabled": self.father.framework.machine.info["spindle"][0]["enabled"],
                             "direction": self.father.framework.machine.info["spindle"][0]["direction"],
@@ -78,13 +78,37 @@ class Status:
                         "default_angular_velocity": float(inifile.find("DISPLAY", "DEFAULT_ANGULAR_VELOCITY"))
                     }
 
-                    self.father.framework.machine.info["user_data"] = user_data
+                    self.father.framework.machine.axes = user_data["axes"]
+
+                    axis_tmp = copy.copy(self.father.framework.machine.info["axis"])
+                    g_offset_tmp = copy.copy(self.father.framework.machine.info["actual_position"])
+                    g5x_offset_tmp = copy.copy(self.father.framework.machine.info["g5x_offset"])
+                    g92_offset_tmp = copy.copy(self.father.framework.machine.info["g92_offset"])
+                    for i in range(0, len(user_data["axes"])):
+                        actual_position = self.father.framework.machine.info["actual_position"]
+                        axis_name = user_data["axes"][i]
+                        axis_num = self.father.framework.machine.get_axis_num(axis_name)
+                        axis = actual_position[axis_num] - g5x_offset_tmp[axis_num] - self.father.framework.machine.info["tool_offset"][axis_num]
+                        axis -= g92_offset_tmp[axis_num]
+                        axis = "{:.3f}".format(axis)
+                        user_data["data"]["position"][i] = axis
+                        g_offset = g_offset_tmp[axis_num]
+                        g_offset = "{:.3f}".format(g_offset)
+                        user_data["data"]["g_offset"][i] = g_offset
+                        g5x_offset = g5x_offset_tmp[axis_num]
+                        g5x_offset = "{:.3f}".format(g5x_offset)
+                        user_data["data"]["g5x_offset"][i] = g5x_offset
+                        g92_offset = g92_offset_tmp[axis_num]
+                        g92_offset = "{:.3f}".format(g92_offset)
+                        user_data["data"]["g92_offset"][i] = g92_offset
+                        user_data["data"]["velocity"][i] = int(axis_tmp[i]['velocity'])
 
                     if user_data["task_state"] == 4:
                         self.father.framework.machine.task_state = True
                     else:
                         self.father.framework.machine.task_state = False
 
+                    self.father.framework.machine.info["user_data"] = user_data
+
                     self.father.framework.utils.service.service_write({"command": "launch:machine:info", "message": "", "data": self.father.framework.machine.info})
             self.father.framework.utils.set_sleep(0.05)
-
